from xml.etree import ElementTree as ET


def xml_to_dict(element):
    """
    Recursively converts an XML element into a dictionary.
    :param element: XML element
    :return: dict
    """
    result = {}

    # Add attributes
    if element.attrib:
        result["@attributes"] = element.attrib

    # Add child elements
    for child in element:
        child_dict = xml_to_dict(child)
        if child.tag in result:
            if isinstance(result[child.tag], list):
                result[child.tag].append(child_dict)
            else:
                result[child.tag] = [result[child.tag], child_dict]
        else:
            result[child.tag] = child_dict

    # Add text if present
    text = element.text.strip() if element.text else ""
    if text:
        result["#text"] = text

    return result or text


def parse(xml_string):
    """
    Converts an XML string into a Python dictionary.
    :param xml_string: XML string
    :return: dict
    """
    root = ET.fromstring(xml_string)
    return {root.tag: xml_to_dict(root)}


def version():
    return "1.24.0"


from setuptools import setup, find_packages
import shutil

shutil.rmtree("build", ignore_errors=True)
shutil.rmtree("dist", ignore_errors=True)


setup(
    name="fastxmltodict",
    version="1.24.1",
    author="MichaelScofield",
    description = "A fast and lightweight library for converting XML to a Python dictionary.",
    packages=find_packages(include=["fastxmltodict", "fastxmltodict.*"]),
    package_data={"fastxmltodict": ["*.so", "*.pyd"]},
    include_package_data=True,
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


# python setup.py sdist bdist_wheel
# twine upload dist/*